@@ -1,6 +1,9 @@
 """Word Level Tokenizer."""
+from typing import Any
+from typing import List
 from typing import Optional
 
+from konoha.konoha_token import Token
 from konoha import word_tokenizers
 from konoha import resource
 
@@ -17,7 +20,7 @@ class WordTokenizer:
             model_path: Optional[str] = None,
             mode: Optional[str] = None,
             dictionary_format: Optional[str] = None,
-    ):
+    ) -> None:
         """Create tokenizer.
 
         Keyword Arguments:
@@ -35,10 +38,11 @@ class WordTokenizer:
         self.model_path = model.path
         self.mode = mode.lower() if mode is not None else None
         self.dictionary_format = dictionary_format
+        self.tokenizer = None  # type: Any
 
-        self.__setup_tokenizer()
+        self._setup_tokenizer()
 
-    def __setup_tokenizer(self):
+    def _setup_tokenizer(self) -> None:
         if self._tokenizer == "character":
             self.tokenizer = word_tokenizers.CharacterTokenizer()
 
@@ -48,12 +52,15 @@ class WordTokenizer:
         if self._tokenizer == "kytea":
             self.tokenizer = word_tokenizers.KyTeaTokenizer(
                 with_postag=self.with_postag,
-                model_path=self.model_path
+                model_path=self.model_path,
             )
 
         if self._tokenizer == "sentencepiece":
+            if self.model_path is None:
+                raise ValueError("`model_path` must be specified for sentencepiece.")
+
             self.tokenizer = word_tokenizers.SentencepieceTokenizer(
-                model_path=self.model_path
+                model_path=self.model_path,
             )
 
         if self._tokenizer == "mecab":
@@ -67,21 +74,24 @@ class WordTokenizer:
         if self._tokenizer == "janome":
             self.tokenizer = word_tokenizers.JanomeTokenizer(
                 user_dictionary_path=self.user_dictionary_path,
-                with_postag=self.with_postag
+                with_postag=self.with_postag,
             )
 
         if self._tokenizer == "sudachi":
+            if self.mode is None:
+                raise ValueError("`mode` must be specified for sudachi.")
+
             self.tokenizer = word_tokenizers.SudachiTokenizer(
                 mode=self.mode,
-                with_postag=self.with_postag
+                with_postag=self.with_postag,
             )
 
-    def tokenize(self, text: str):
+    def tokenize(self, text: str) -> List[Token]:
         """Tokenize input text"""
         return self.tokenizer.tokenize(text)
 
     @property
-    def name(self):
+    def name(self) -> str:
         return self.tokenizer.name
 
 
